@@ -1,5 +1,5 @@
 from datetime import date, datetime
-from typing import List, Union
+from typing import List, Union, Dict
 
 from PyYandexLMS.models.user import User
 
@@ -17,7 +17,7 @@ class BaseProfile(User):
     city: str
     clubs: str
     competitions: str
-    parents_info: List[str]
+    parents_info: Union[List[str], Dict]
     programming_experience: str
     school: str
     school_class: str
