@@ -1,7 +1,8 @@
-from typing import List, Union
+from typing import List, Optional, Union
 
 from PyYandexLMS.models.base.main import BaseModel
 from PyYandexLMS.models.base.task import BaseTask
+from PyYandexLMS.models.problem import DetailedProblem
 from PyYandexLMS.models.submission import Submission
 from PyYandexLMS.models.variant import Variant
 
@@ -19,4 +20,5 @@ class TaskType(BaseModel):
     type: str
     color: str
     order: int
-    tasks: List[BaseTask]
+    tasks: Optional[List[BaseTask]]
+    problems: Optional[List[DetailedProblem]]
